(function($, win)
{
    var wpsight = win.wpsight = win.wpsight || {};

    var labels     = __wpsight_contact_labels;

    var numReg   = /[^0-9\.]/g;   
    var emailReg = /^([\w-\.]+@([\w-]+\.)+[\w-]{2,4})?$/;

    var attachError = function($field, msg) {
        $field.parent().append($(document.createElement('div')).addClass('form-field-error').html(msg));
    };

    var checkField = function($field, $form, done)
    {
        var $fieldWrap = $field.parent();
        var val = $.trim($field.val());
        var hasError = false;

        ///
        /// Empty checks
        ///

        // checkbox
        if( $field.hasClass('wrap-field-checkbox') ) {
            var name = $field.find('.checkbox').attr('name');
            if( $('input[name="' + name + '"]:checked').length == 0 ) {
                attachError($field, labels['field_error']);
                hasError = true;
            }
        }
        
        // radio
        else if( $field.hasClass('wrap-field-radio') ) {
            var name = $field.find('.radio').attr('name');
            if( $('input[name="' + name + '"]:checked').length == 0 ) {
                attachError($field, labels['field_error']);
                hasError = true;
            }
        }

        // generic
        else if (val == '' && $field.hasClass('required') && $field.attr('name') !== undefined) {
            $('.listing-contact').height('auto');
            attachError($field, labels['field_error']);
            hasError = true;
        }

        ///
        /// Value checks
        ///

        // email
        if($field.hasClass('email')) {

            if(!emailReg.test(val)) {
                $('.listing-contact').height('auto');

                attachError($field, labels['email_error']);
                hasError = true;
            }
        }

        // numbers
        else if($field.hasClass('numbers') && val != '') {
        
            if(numReg.test(val.replace(/ /g,''))) {
                $('.listing-contact').height('auto');
                attachError($field, labels['number_error']);
                hasError = true;
            }
        }

        // captcha
        else if($field.hasClass('input-captcha')) {

            if(val != '') {

                var url = $form.attr('action');
                url += ((url.indexOf('?') === -1) ? '?' : '&') + '__wpsight_contact_captcha=y';

                $.ajax({
                    type: "POST",
                    url: url,
                    dataType: 'text' ,
                    data: {code: val},
                    success: function(res)
                    {
                        if(res*1 !== 1)
                        {
                            $('.listing-contact').height('auto');
                            attachError($field, labels['captcha_error']);
                            done(true);
                        }
                        else
                        {
                            done(false);
                        }
                    }
                });

                return;
            }
        }

        // emulate async
        window.setTimeout(done, 0, hasError);
    };

    var submitForm = function($form)
    {
        //console.log("submit form!");

        $('#contact-footer').fadeOut('normal', function() {
            $form.find('.loading-indicator').show();
        });
        var formInput = $form.serialize();
        $.post($form.attr('action'),formInput, function(data){

            $(document).trigger('wpsight_form_sent', [$form,formInput]);

            $form.slideUp(150, function() {
                $('.listing-contact').height('auto');              
                $form.before('<div class="form-field-confirm"><p>' + labels['confirm'] + '</p></div>');
            });
        });
    };

    wpsight.contact = function() {

        // calling this forms as we could theoretically have multiple instances
        // of the contact form within one page
        var $forms = $('#wpsight-contact-form');

        $forms.each(function()
        {
            var $form = $(this);

            var captchaEnabled = !!$form.find('.captcha-image').length;

            $form.submit(function(e) {

                e.preventDefault();

                // remove error indicators
                $form.find('.form-field-error').remove();

                var hasError = false;
                var checksRunning = 0;

                $form.find('.required, .numbers').each(function() {

                    checksRunning++;

                    checkField($(this), $form, function(error)
                    {
                        if(error)
                            hasError = true;

                        if(--checksRunning == 0 && !hasError)
                            submitForm($form);
                    });
                });
                
                return false;
                
            });
        }); 
    };

    $(wpsight.contact);

})(jQuery, window);
