<?php
/**
 * Using a class here to make contact system more self-contained
 */
class wpsight_contact_form
{
	private static $_instance;

	protected $_times_rendered = 0;

	public static function instance()
	{
		if(!self::$_instance)
		{
			self::$_instance = new self();

			/*
			 * explicitly call custom constructor to prevent
			 * infinite loops when calling instance() from __construct()
			 * directly/indirectly
			 */
			self::$_instance->_init();
		}

		return self::$_instance;
	}

	protected function _init()
	{
		add_action('wpsight_contact_form', array(&$this, 'render'), 10, 3);

		// used for lazily enqueuing assets
		add_action('wp_footer', array(&$this, 'enqueue_assets'));

		add_action('parse_request', array(&$this, 'parse_request'));
	}

	public function enqueue_assets()
	{
		if(!$this->_times_rendered)
			return;

		wp_enqueue_script('wpsight-contact', WPSIGHT_ASSETS_JS_URL . '/wpsight.contact.min.js', array('jquery'), '0.1');

		$labels = apply_filters('wpsight_contact_js_labels', wpsight_contact_labels());

		wp_localize_script('wpsight-contact', '__wpsight_contact_labels', $labels);
	}

	public function parse_request()
	{
		if(isset($_GET['__wpsight_contact_captcha']))
		{
		    @session_start();
		    if ( isset( $_POST['code'] ) ) {
		    	if( strtolower( $_POST['code'] ) != $_SESSION['securimage_code_value']['default'] ) {
		            echo json_encode( -1 ); //code wrong
		        } else {
		            echo json_encode( 1 ); //code correct
		        }
		     } else {
		        echo json_encode( -2 ); //argument error
		     }
		     exit;
		}
	}

	public function render($location = false, $args = false, $context = array())
	{
		++$this->_times_rendered;

		// Don't show when password required
		if( post_password_required() )
			return;
	        	
		// Get contact fields
		$fields = wpsight_contact_fields();
		
		// Get contact labels
		$labels = wpsight_contact_labels();
		
		// Get captcha image class
		require_once WPSIGHT_ADMIN_DIR . '/captcha/securimage.php';
	
		if( isset( $_POST['submitted'] ) ) {
		
			// will poplulate $errors and $values
			extract($this->_handle_submit($fields, $labels));

			if(empty($errors))
			{
				$success = $this->_send_mail($location, $values, $args);
				?>
				<div class="form-field-confirm">
				    <p><?php echo $success ? $labels['confirm'] : $labels['sending_failed'] ?></p>
				</div>
				<?php
				return;
			}
			else
			{
				?>
		        <div class="form-error form-field-error">
		        	<?php echo $labels['error']; ?>
		        </div>
				<?php
			}
		
		}
		else
		{
			$errors = array();
			$values = array();
		}

		do_action( 'wpsight_contact_form_fields', $_POST, $location, $errors );
	}

	protected function _handle_submit($fields, $labels)
	{
		global $post, $securimage;

		$errors = array();
		$values = array();

		if( $fields['captcha']['show'] == true ) {
			if( isset( $_POST['captcha_code'] ) ) {

				$securimage = new Securimage();
		    	    
		    	if( strtolower( $_POST['captcha_code'] ) != $securimage->getCode() ){
		    	    $errors['captcha'] = '<div class="form-field-error">'. $labels['captcha_error'] . '</div>';
		    	}
		    	    
			} else {

				$errors['captcha'] = '<div class="form-field-error">'. $labels['argument_error'] . '</div>';
		    }
		}

	    foreach( $fields as $k => $v ) {
	    
		    if( $k == 'captcha' || $k == 'copy' )
		    	continue;
		
		    $field = $v['id'];

		    $val = isset($_POST[$field]) ? $_POST[$field] : null;

		    if($val && !is_array($val))
		    	$val = trim($val);

		    if( $v['required'] && empty($val)) {
		    	$errors[$field] = '<div class="form-field-error">'. $labels['field_error'] . '</div>';

		    } elseif( $v['type'] === 'numbers' && !empty($val) ) {

		    	if( is_numeric( str_replace( ' ', '', $val) ) === false ) {		    	
		    		$errors[$field] = '<div class="form-field-error">'. $labels['number_error']. '</div>';
		    	} else {
		    		$values[$field] = $val;
		    	}
		    
		    } elseif( $v['required'] === 'email' ) {
		    
		    	if( filter_var( $val, FILTER_VALIDATE_EMAIL ) === false ) {		    	
		    		$errors[$field] = '<div class="form-field-error">'. $labels['email_error'] . '</div>';
		    	} else {
		    		$values[$field] = $val;
		    	}
		    
		    } else {
		    
		    	if( ! is_array( $val ) ) {
		    	    $values[$field] = stripslashes( nl2br( $val ) );
		    	} else {
		    	    $values[$field] = $val;
		    	    foreach ( $values[$field] as &$value )
		    		    $value = stripslashes( trim ( $value ) );
		    	}
		    
		    }
		    
		} // end foreach

		return array('values' => $values, 'errors' => $errors);
	}

	protected function _send_mail($location, $values, $args = array())
	{
        $sender = $this->_get_sender();

        $opts = array();
        $data = array('sender_name' => $sender['name'], 'sender_email' => $sender['email']);

        $transport = wpsight_get_option('mail_transport');

        if($transport == 'smtp')
        {
        	$opts['transport'] = $transport;
        	$opts['smtp_host'] = wpsight_get_option('mail_smtp_host');
        	$opts['smtp_port'] = (int)wpsight_get_option('mail_smtp_port');
         	$opts['smtp_user'] = wpsight_get_option('mail_smtp_user');
        	$opts['smtp_pass'] = wpsight_get_option('mail_smtp_pass');
        	$opts['smtp_sec']  = wpsight_get_option('mail_smtp_sec');
        }

    	// Create email message
    	$email = wpsight_contact_email( $_POST, $location, $values );
    
		// Set email to featured agent
		if( ! empty( $values['contact_agent'] ) && $user = get_userdata($values['contact_agent']) )
			$email_to = $user->user_email;

		// use widget args
		else if( ! empty( $args['email'] ) )
			$email_to = sanitize_email( $args['email'] );

		// fall back to post author
		else
			$email_to = get_the_author_meta( 'email' );	

		// use meta field
		
		$email_meta = get_post_meta( get_the_ID(), 'contact_email', true );
		
		if( ! empty( $email_meta ) )
		    $email_to = sanitize_email( $email_meta );

		// Filter final $email_to
		$email_to = apply_filters( 'wpsight_contact_email_to', $email_to, $_POST, $location, $values );

        $data['recipients'] = array($email_to);
        $data['subject']    = $email['subject'];
        $data['body']       = array('html' => $email['body']);
        $data['reply_to']   = $values['contact_email'];

        $data = apply_filters('wpsight_contact_form_email_data', $data);
        $opts = apply_filters('wpsight_contact_form_email_opts', $opts);

        wpsight_mail_send_email($data, $opts);

        // Optionally send copy			    		
        
        if( !empty($_POST['copy']) )
        {
        	$data['recipients'] = array($values['contact_email']);
        	$data['reply_to']   = $email_to;

        	$data = apply_filters('wpsight_contact_form_email_data_copy', $data);
        	$opts = apply_filters('wpsight_contact_form_email_opts_copy', $opts);

        	wpsight_mail_send_email($data, $opts);
        } 
        
        // Actions hook after email has been sent
        do_action( 'wpsight_contact_form_sent', get_the_ID(), $email_to, $email, $location, $values, array(), $_POST );

        return true;
	}

	protected function _get_sender()
	{
		$name  = wpsight_get_option('mail_sender_name');
		$email = wpsight_get_option('mail_sender_email');

		$defaults = wpsight_mail_get_default_sender();

		if(empty($name))
			$name = $defaults['name'];

		if(empty($email))
			$email = $defaults['email'];

		return apply_filters('wpsight_contact_sender', array('email' => $email, 'name' => $name));
	}
}

wpsight_contact_form::instance();

/**
 * Wrapper for new class-based render method. Deprecated.
 *
 * @since 1.1
 * @deprecated
 * @todo find out if this is is required at all.
 */

function wpsight_do_contact_form( $location = false, $args = false ) {
	wpsight_contact_form::instance()->render($location, $args);
}

/**
 * Create contact form fields
 *
 * @since 1.2
 */
 
add_action( 'wpsight_contact_form_fields', 'wpsight_do_contact_form_fields', 10, 3 );

function wpsight_do_contact_form_fields( $get_post, $location = false, $field_errors = false ) {

	// Get contact fields
	$contact_fields = wpsight_contact_fields();

	// Get contact labels
	$contact_labels = wpsight_contact_labels();
	
	// Set URL optionally with fav=1
	$permalink = $location == 'favorites' ? add_query_arg( array( 'fav' => '1' ) ) : get_permalink(); ?>

	<form action="<?php echo esc_url( $permalink ); ?>" id="wpsight-contact-form" method="post">
	
	    <?php					    	
	    	// Add action hook before form fields
	    	do_action( 'wpsight_contact_fields_before', $get_post, $location );
	    
	    	// Build form output
	    	$form = '';
	    
	    	foreach( $contact_fields as $field => $v ) {
	    	
	    		if( $field == 'captcha' || $field == 'copy' )
	    			continue;
	    			
	    		// Set field parameters
	    	
	    		$field 		  = isset( $v['id'] ) ? $v['id'] : false;

	    		$field_value  = isset( $get_post[$field] ) ? $get_post[$field] : false;
	    		$field_value  = ( isset( $v['value'] ) && ! empty( $v['value'] ) ) ? $v['value'] : $field_value;

	    		$field_req      = ( isset( $v['required'] ) && $v['required'] ) ? ' required' : '';
	    		$field_disabled = ( isset( $v['disabled'] ) && $v['disabled'] ) ? ' disabled' : '';
	    		$field_hidden   = ( isset( $v['type'] ) && $v['type'] == 'hidden' ) ? ' hidden' : false;
	    			
	    		// Add action hook before form field
	    		do_action( 'wpsight_listing_contact_field_' . $field . '_before', $field, $v, $get_post, $location );
	
	    		// Set indexes
	
	    		$v['type'] 	 	 = isset( $v['type'] ) ? $v['type'] : false;
	    		$v['before'] 	 = isset( $v['before'] ) ? $v['before'] : false;
	    		$v['label']  	 = isset( $v['label'] ) ? $v['label'] : false;
	    		$v['after']  	 = isset( $v['after'] ) ? $v['after'] : false;
	    		$v['class']  	 = isset( $v['class'] ) ? ' ' . $v['class'] : false;
	    		$v['class_wrap'] = isset( $v['class_wrap'] ) ? ' ' . $v['class_wrap'] : false;
	    		
	    		// Create form field
	    
	    		$form .= '<div class="wrap-field wrap-field-type-' . $v['type'] . ' wrap-' . $field . $field_hidden . $v['class_wrap'] . '">';
	    		
	    			if( $v['before'] )
	    				$form .= $v['before'];
	    		
	    			if( $v['label'] )
	    				$form .= '<label for="' . $field . '">' . $v['label'] . ':</label>' . "\n";
	    			
	    			if( $v['type'] == 'text' || $v['type'] == 'numbers' ) {
	    				
	    				$class = $v['type'] == 'numbers' ? ' numbers' : false;
	    				$email = $v['required'] === 'email' ? ' email' : false;

	    				$form .= '<input type="text" name="' . $field . '" value="' . $field_value . '" id="id-' . $field . '" class="' . $field . ' text' . $class . $email . $field_req . $field_disabled . $v['class'] . '" ' . $field_disabled . ' />' . "\n";

	    			} elseif( $v['type'] == 'select' ) {
	    			
	    				if( ! empty( $v['data'] ) ) {
	    			
	    					$form .= '<select name="' . $field . '" id="id-' . $field . '" class="' . $field . ' select' . $field_req . $field_disabled . $v['class'] . '" ' . $field_disabled . ' />' . "\n";    					
	    					
	    						foreach( $v['data'] as $option => $label ) {
	    						
	    							$form .= '<option value="' . $option . '" ' . selected( $option, $field_value, false ) . '>' . $label . '</option>';
	    						
	    						} // endforeach
	    					
	    					$form .= '</select>' . "\n";
	    				
	    				} // endif
	    			
	    			} elseif( $v['type'] == 'checkbox' ) {
	    			
	    				if( ! empty( $v['data'] ) ) {
	    				
	    					// Set counter
	    					$counter = 1;
	    					
	    					foreach( $v['data'] as $option => $label ) {
	    					
	    						$field_req = ( $counter == 1 ) ? $field_req : false;
	    						$field_defaults = is_array( $field_value ) && in_array( $option, $field_value ) ? $option : $field_value;
	    					
	    					    $form .= '<div class="wrap-field-checkbox wrap-field-checkbox-' . $field . $field_req . '"><label>';
	    					    $form .= '<input type="checkbox" name="' . $field . '[]" id="id-' . $field . '-' . $counter . '" class="' . $field . ' checkbox' . $v['class'] . '" value="' . $option . '" ' . checked( $option, $field_defaults, false ) . '>' . $label;
	    					    $form .= '</label></div><!-- .wrap-field-checkbox wrap-field-checkbox-' . $field . ' -->';
	    					    
	    					    // Increase counter
	    					    $counter++;
	    					
	    					} // endforeach
	    				
	    				} // endif
	    			
	    			} elseif( $v['type'] == 'radio' ) {
	    			
	    				if( ! empty( $v['data'] ) ) {
	    				
	    					// Set counter
	    					$counter = 1;
	    					
	    					foreach( $v['data'] as $option => $label ) {
	    					
	    						$field_req = ( $counter == 1 ) ? $field_req : false;
	    						$field_checked = ( $field_value == false && $counter == 1 ) ? checked( 1, 1, false ) : checked( $option, $field_value, false );
	    					
	    					    $form .= '<div class="wrap-field-radio wrap-field-radio-' . $field . $field_req . '"><label>';
	    					    $form .= '<input type="radio" name="' . $field . '[]" id="id-' . $field . '-' . $counter . '" class="' . $field . ' radio' . $v['class'] . '" value="' . $option . '" ' . $field_checked . '>' . $label;
	    					    $form .= '</label></div><!-- .wrap-field-radio wrap-field-radio-' . $field . ' -->';
	    					    
	    					    // Increase counter
	    					    $counter++;
	    					
	    					} // endforeach
	    				
	    				} // endif
	    			
	    			} elseif( $v['type'] == 'textarea' ) {
	    				$form .= '<textarea name="' . $field . '" rows="20" cols="30" id="id-' . $field . '" class="' . $field . ' text' . $field_req . $field_disabled . $v['class'] . '" ' . $field_disabled . '>' . $field_value . '</textarea>' . "\n";
	    			} elseif( $v['type'] == 'hidden' ) {
	    				$form .= '<input type="hidden" name="' . $field . '" id="id-' . $field . '" value="' . $field_value . '" />' . "\n";
	    			}
	    			
	    			if( isset( $field_errors[$field] ) )
	    				$form .= $field_errors[$field];
	    				
	    			if( $v['after'] )
	    				$form .= $v['after'];
	    		
	    		$form .= '</div><!-- .wrap-' . $field . ' -->';
	    		
	    		// Add action hook after form field
	    		do_action( 'wpsight_listing_contact_field_' . $field . '_after', $field, $v, $get_post, $location );
	    	
	    	}
	    	
	    	echo $form;
	    
	    ?>
	    
	    <?php if( isset( $contact_fields['captcha'] ) && $contact_fields['captcha']['show'] == true ) { ?>
	    
	    <div class="wrap-field wrap-captcha clearfix">
	
	    	<?php
	    	    $captcha_width = $contact_fields['captcha']['image_width'];
	    	    $captcha_height = $contact_fields['captcha']['image_height'];
	    	?>
	    	
	    	<div class="captcha-image">
	    	
	    		<img id="captcha" src="<?php echo WPSIGHT_ADMIN_URL; ?>/captcha/securimage_show.php" width="<?php echo $captcha_width; ?>" height="<?php echo $captcha_height; ?>" alt="Captcha" />
	    		<a href="#" onclick="document.getElementById('captcha').src = '<?php echo WPSIGHT_ADMIN_URL; ?>/captcha/securimage_show.php?' + Math.random(); return false">[ <?php _e( 'Reload Image', 'wpsight' ); ?> ]</a>
	    	
	    	</div>
	    	
	    	<div class="captcha-input">
	    	
	    		<input type="text" name="captcha_code" id="captcha_code" size="5" maxlength="6" class="input-captcha required" />
	    	
	    		<?php if( isset( $field_errors['captcha'] ) ) echo $field_errors['captcha']; ?>
	    	
	    	</div>
	
	    </div><!-- .wrap-captcha -->
	    
	    <?php } // endif $contact_fields['captcha']['show'] ?>
	    
	    <div id="contact-footer" class="wrap-field clearfix">
	        
	        <div class="contact-buttons">
	        	<input type="hidden" name="submitted" id="submitted" value="true" />
	        	<input type="submit" class="<?php echo apply_filters( 'wpsight_button_class_contact', 'btn btn-large' ); ?>" value="<?php echo $contact_labels['submit']; ?>" />
	        </div><?php
	
	        if( isset( $contact_fields['copy'] ) && $contact_fields['copy']['show'] == true ) {
	
	        $get_post['copy'] = isset( $get_post['copy'] ) ? $get_post['copy'] : false; ?>
	    
	        <div class="contact-copy">
	        	<label class="checkbox">
	        		<input type="checkbox" name="copy" value="true"<?php checked( $get_post['copy'], true ); ?> />
	        		<?php echo $contact_labels['copy']; ?>
	        	</label>
	        </div>
	        
	        <?php } // endif $contact_fields['copy']['show'] ?>
	    
	    </div><!-- #contact-footer -->
	    
	    <?php
	    	// Add action hook after form fields
	    	do_action( 'wpsight_contact_fields_after', $get_post, $location );
	    ?>

	    <p class="loading-indicator" style="display: none"><img src="<?php echo WPSIGHT_ADMIN_IMG_URL; ?>/loading.gif" alt="<?php _e( 'Loading', 'wpsight' ); ?>&hellip;" height="22" width="22" /></p>
	
	</form><?php

}

/**
 * Add list of favorite listings
 * to form on contact page template
 *
 * @since 1.2 
 */
 
add_filter( 'wpsight_contact_fields', 'wpsight_contact_field_favorites' );

function wpsight_contact_field_favorites( $fields ) {

	if( ! isset( $_GET['fav'] ) || $_GET['fav'] != '1' || empty( $_COOKIE[WPSIGHT_COOKIE_FAVORITES] ) )
		return $fields;
		
	// Get listing IDs stored in cookie
	$favorites = explode( ',', $_COOKIE[WPSIGHT_COOKIE_FAVORITES] );
	
	$data = array();
	
	foreach( $favorites as $favorite ) {
		// Check if listing publish
		if( get_post_status( $favorite ) != 'publish' )
		    continue;
		$data[$favorite] = '<strong>' . wpsight_get_listing_id( $favorite ) . ':</strong> <a href="' . get_permalink( $favorite ) . '">' . get_the_title( $favorite ) . '</a>';
	}

	$fields['favorites'] = array(		
		'id'            => 'favorites',
        'label'         => __( 'Your favorites', 'wpsight' ),
        'required'      => false,
        'type'          => 'checkbox',
        'placeholder'   => false,
        'before'        => false,
        'after'         => '<div class="description">' . __( 'Please check the listings you wish to receive information about', 'wpsight' ) . '</div>',
        'value'         => $favorites,
        'data'          => $data,
        'position'      => 35
	);
	
	return $fields;

}

/**
 * Add agent info before form
 * fields on contact page template
 *
 * @since 1.2 
 */
 
add_action( 'wpsight_contact_fields_before', 'wpsight_contact_fields_agent_info' );

function wpsight_contact_fields_agent_info() {

	$author_slug = apply_filters( 'wpsight_author_slug', 'agent' );
	
	if( isset( $_GET[$author_slug] ) )
		$agent = get_userdata( $_GET[$author_slug] );
	
	if( isset( $agent ) && is_object( $agent ) )
		echo '<div class="alert">' . sprintf( __( 'Your message will be sent to %s', 'wpsight' ), $agent->display_name ) . '</div>';

}

/**
 * Add featured agent email
 * to form on contact page template
 *
 * @since 1.2 
 */
 
add_filter( 'wpsight_contact_fields', 'wpsight_contact_field_agent' );

function wpsight_contact_field_agent( $fields ) {

	$author_slug = apply_filters( 'wpsight_author_slug', 'agent' );

	$agent = null;

	if(isset($_POST['contact_agent']))
		$agent = $_POST['contact_agent'];

	else if(isset($_GET[$author_slug]))
		$agent = $_GET[$author_slug];

	if( !$agent || !($agent = get_userdata($agent)) || !is_object($agent) )
		return $fields;

	$fields['contact_agent'] = array(		
		'id'            => 'contact_agent',
        'label'         => false,
        'type'          => 'hidden',
        'value'         => $agent->ID,
        'position'      => 50
	);
	
	return $fields;
}
