<?php

/**
 * from wp-mail() in wp-includes/pluggable.php
 *
 * We don't make this function pluggable as the
 * generated output is just used for presentation purposes
 * in wpsight_contact_options() emulating WP's default behavior
 */
function wpsight_mail_get_default_sender() {
    $sitename = strtolower( $_SERVER['SERVER_NAME'] );
    if ( substr( $sitename, 0, 4 ) == 'www.' )
        $sitename = substr( $sitename, 4 );

    $email = 'wordpress@' . $sitename;
    $name  = get_bloginfo('name');

    if(empty($name))
        $name = 'WordPress';

    return array('email' => $email, 'name' => $name);
}



add_filter('wpsight_options', 'wpsight_mail_options');

function wpsight_mail_options($options) {

    $opts = array();

    $sender = wpsight_mail_get_default_sender();
            
    $opts['heading_mail'] = array(
        'name' => __( 'Mailing', 'wpsight' ),
        'id'   => 'heading_mail',
        'type' => 'heading'
    );

    $opts['mail_sender_email'] = array( 
        'name' => __( 'Sender Email', 'wpsight' ),
        'desc' => sprintf( __( 'Carefully choose the desired sender email address.
            Ideally choose one that\'s hosted at your web host as well.
            Misconfiguration may lead to false-positive spam detection.
            Leave empty to use default: <code>%s</code>', 'wpsight' ), $sender['email']),
        'id'   => 'mail_sender_email',
        'std'  => '',
        'type' => 'text',
    );

    $opts['mail_sender_name'] = array( 
        'name' => __( 'Sender Name', 'wpsight' ),
        'desc' => sprintf( __( 'Relates to the email address specified above.
            Leave empty to use default: <code>%s</code>', 'wpsight' ), $sender['name']),
        'id'   => 'mail_sender_name',
        'std'  => '',
        'type' => 'text'
    );

    $opts['mail_transport'] = array( 
        'name' => __( 'Mail Transport', 'wpsight' ),
        'desc' => __( 'SMTP or native', 'wpsight' ),
        'id'   => 'mail_transport',
        'std'  => 'native',
        'type' => 'select',
        'options' => array(
            'native' => __('Native', 'wpsight'),
            'smtp'   => __('SMTP', 'wpsight'),
        )
    );

    $opts['mail_smtp_host'] = array( 
        'name' => __( 'SMTP Host', 'wpsight' ),
        'desc' => __( 'The server to use, e.g. smtp.provider.com', 'wpsight' ),
        'id'   => 'mail_smtp_host',
        'std'  => '',
        'type' => 'text',
		'class' => 'hidden'
    );

    $opts['mail_smtp_port'] = array( 
        'name' => __( 'SMTP Port', 'wpsight' ),
        'desc' => __( 'The SMTP port to use, usually 25', 'wpsight' ),
        'id'   => 'mail_smtp_port',
        'std'  => 25,
        'type' => 'text',
		'class' => 'hidden'
    );

    $opts['mail_smtp_sec'] = array( 
        'name' => __( 'SMTP Encryption', 'wpsight' ),
        'desc' => __( 'Whether to use SMTP encryption', 'wpsight' ),
        'id'   => 'mail_smtp_sec',
        'std'  => '',
        'type' => 'select',
        'options' => array(
            ''    => __('None', 'wpsight'),
            'tls' => __('TLS', 'wpsight'),
            'ssl' => __('SSL', 'wpsight'),
        ),
		'class' => 'hidden'
    );

    $opts['mail_smtp_user'] = array( 
        'name' => __( 'SMTP User', 'wpsight' ),
        'desc' => __( 'SMTP User. Leave empty if your SMTP server doesn\'t require authentication', 'wpsight' ),
        'id'   => 'mail_smtp_user',
        'std'  => '',
        'type' => 'text',
		'class' => 'hidden'
    );

    $opts['mail_smtp_pass'] = array( 
        'name' => __( 'SMTP Password', 'wpsight' ),
        'desc' => __( 'SMTP Password. Might be empty.', 'wpsight' ),
        'id'   => 'mail_smtp_pass',
        'std'  => '',
        'type' => 'text',
		'class' => 'hidden'
    );

    return array_merge($options, apply_filters('wpsight_mail_options', $opts));
}



if(!function_exists('wpsight_mail_send_email'))
{
    function wpsight_mail_send_email($data = array(), $opts = array())
    {
        if(!class_exists('PHPMailer'))
            require ABSPATH . '/wp-includes/class-phpmailer.php';

        $mail = new PHPMailer();
        $mail->CharSet = 'UTF-8';

        foreach($data['recipients'] as $addr)
        {
            if(is_array($addr))
                $mail->AddAddress($addr[0], $addr[1]);
            else
                $mail->AddAddress($addr);
        }

        $mail->Subject = isset($data['subject']) ? $data['subject'] : null;

        if(is_array($data['body']) && isset($data['body']['html']))
        {
            $mail->isHTML(true);
            $mail->Body = $data['body']['html'];
            $mail->AltBody = isset($data['body']['text']) ? $data['body']['text'] : null;
        }

        $mail->From     = $data['sender_email'];
        $mail->FromName = $data['sender_name'];

        if(isset($data['reply_to']))
        {
            foreach((array)$data['reply_to'] as $addr)
            {
                if(is_array($addr))
                    $mail->AddReplyTo($addr[0], $addr[1]);
                else
                    $mail->AddReplyTo($addr);
            }
        }

        if(isset($data['attachments']) && is_array($data['attachments']))
        {
            foreach($data['attachments'] as $attachment)
            {
                $encoding = isset($attachment['encoding']) ? $attachment['encoding'] : 'base64';
                $type     = isset($attachment['type']) ? $attachment['type'] : 'application/octet-stream';

                $mail->AddStringAttachment($attachment['data'], $attachment['filename'], $encoding, $type);
            }
        }

        if(isset($opts['transport']) && $opts['transport'] == 'smtp')
        {
            $mail->isSMTP();
            $mail->Host = $opts['smtp_host'];
            $mail->Port = isset($opts['smtp_port']) ? (int)$opts['smtp_port'] : 25;

            if(!empty($opts['smtp_user']))
            {
                $mail->Username = $opts['smtp_user'];
                $mail->Password = $opts['smtp_pass'];
            }

            if(!empty($opts['smtp_sec']))
                $mail->SMTPSecure = $opts['smtp_sec'];
        }

        do_action('wpsight_mail_pre_send', $mail, $data, $opts);

        return $mail->send() ? true : $mail->ErrorInfo;

    }
}

/* 
 * Show/hide options when checkbox is clicked
 */

add_action( 'wpsight_options_custom_scripts', 'wpsight_toggle_options_mail' );

function wpsight_toggle_options_mail() { ?>

<script type='text/javascript'>
jQuery(document).ready(function($) {

	var totoggle_smtp = '#section-mail_smtp_host, #section-mail_smtp_port, #section-mail_smtp_sec, #section-mail_smtp_user, #section-mail_smtp_pass';	
	
	$('#mail_transport').change(function() {
	  	if( $(this).val() == 'smtp' ) {
  			$(totoggle_smtp).fadeIn(150);
		} else {
			$(totoggle_smtp).fadeOut(150);
		}
	});
	
	if ($('#mail_transport').val() == 'smtp') {
		$(totoggle_smtp).show();
	}
	
});
</script><?php

}
