<?php

/**
 * Create listing title widget
 *
 * @package wpSight
 * @subpackage Widgets
 * @since 1.0
 */
 
/**
 * Register widget
 */
 
add_action( 'widgets_init', 'wpsight_register_widget_listing_title' );
 
function wpsight_register_widget_listing_title() {

	register_widget( 'wpSight_Listing_Title' );

}

/**
 * Widget class
 */
	
class wpSight_Listing_Title extends WP_Widget {
    
    function __construct() {
		$widget_ops = array( 'description' => __( 'Main title on single listing pages', 'wpsight' ) );
		parent::__construct( 'wpSight_Listing_Title', ':: ' . WPSIGHT_NAME . ' ' . _x( 'Listing Title', 'listing widget', 'wpsight' ), $widget_ops );
	}
 
    function widget( $args, $instance ) {
    
    	if( is_singular() && get_post_type() == wpsight_listing_post_type() ) {
    
    		extract( $args, EXTR_SKIP );
        	        
        	$title 			 = apply_filters( 'widget_title', '[' . __( 'Listing Title', 'wpsight' ) . ']', $instance, $this->id_base );
        	$title_listing   = get_the_title( get_the_ID() ); ?>
        	
        	<div id="<?php echo wpsight_dashes( $this->id ); ?>" class="listing-title section clearfix clear">
        		
				<div class="title clearfix">
					<h1 class="entry-title"><?php echo apply_filters( 'wpsight_widget_listing_title', $title_listing, $args, $instance ); ?></h1>
        	    	<?php
        	   		    // Action hook listing title inside
        	   		    do_action( 'wpsight_listing_title_inside', $args, $instance );
        	   		?>    	
        	    </div>
				
			</div><!-- .listing-title --><?php

		}
        
	}

    function update( $new_instance, $old_instance ) {
    
    	$new_instance = ( array ) $new_instance;

        $actions = wpsight_listing_title_actions();

        $instance = array();

        foreach( $actions as $action => $foo ) {
            $field = 'title_' . $action;
            if( isset( $new_instance[$field] ) && filter_var( $new_instance[$field], FILTER_VALIDATE_BOOLEAN ) )
                $instance[$field] = true;
        }

        return $instance;
    }
 
    function form( $instance ) {
		
		// get registered actions
		$actions = wpsight_listing_title_actions();

		//$instance = wp_parse_args( (array) $instance, $defaults );
		$title	  = '[' . __( 'Listing Title', 'wpsight' ) . ']';
?>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="hidden" value="<?php echo esc_attr( $title ); ?>" />
        
        <?php foreach( $actions as $action => $v ) {
         ?>
            <p>
                <input type="checkbox" class="checkbox" id="<?php echo $this->get_field_id( 'title_' . $action ); ?>" name="<?php echo $this->get_field_name( 'title_' . $action ); ?>" <?php echo isset( $instance['title_' . $action] ) ? 'checked' : ''; ?> />
                <label for="<?php echo $this->get_field_id( 'title_' . $action ); ?>"><?php _e( 'Display:', 'wpsight' ); echo ' ' . ucfirst( $action ); ?></label>		
            </p>
            
        <?php }

	}

} // end class wpSight_Listing_Title
